@@ -169,7 +169,7 @@ class Table:
         rs_dict = json.loads(rs)
         id_list = []
         for item in rs_dict['result']['items']:
-            if item['fields'][self._hash_field] == raw_field_value:
+            if self._hash_field in item['fields'] and item['fields'][self._hash_field] == raw_field_value:
                 id_list.append(item['fields'][self._pk_field])
         if len(id_list) == 0:
             resp = {
